@@ -29,11 +29,22 @@ else:
 # Now the path is set, import our applet
 import deskbar, deskbar.DeskbarApplet, deskbar.defs
 
+try:
+	# attempt to set a name for killall
+	import deskbar.osutils
+	deskbar.osutils.set_process_name ("deskbar-applet")
+except:
+	print "Unable to set processName"
+
 import gettext, locale
 gettext.bindtextdomain('deskbar-applet', abspath(join(deskbar.defs.DATA_DIR, "locale")))
+if hasattr(gettext, 'bind_textdomain_codeset'):
+	gettext.bind_textdomain_codeset('deskbar-applet','UTF-8')
 gettext.textdomain('deskbar-applet')
 
 locale.bindtextdomain('deskbar-applet', abspath(join(deskbar.defs.DATA_DIR, "locale")))
+if hasattr(locale, 'bind_textdomain_codeset'):
+	locale.bind_textdomain_codeset('deskbar-applet','UTF-8')
 locale.textdomain('deskbar-applet')
 
 import gtkexcepthook
@@ -95,7 +106,7 @@ if __name__ == "__main__":
 		if cuemiac:
 			deskbar.UI_OVERRIDE = deskbar.CUEMIAC_UI_NAME
 		else:
-			deskbar.UI_OVERRIDE = deskbar.COMPLETION_UI_NAME
+			deskbar.UI_OVERRIDE = deskbar.ENTRIAC_UI_NAME
 
 		import gnome
 		gnome.init(deskbar.defs.PACKAGE, deskbar.defs.VERSION)
