@@ -2,30 +2,30 @@ import xml.sax
 from os.path import join, expanduser, exists
 from gettext import gettext as _
 import gtk
-import deskbar, deskbar.indexer, deskbar.handler
-from deskbar.filewatcher import FileWatcher
-from deskbar.handlers_browsers import get_url_host, is_preferred_browser, on_customize_search_shortcuts, on_entry_key_press, load_shortcuts
-from deskbar.handlers_browsers import BrowserSmartMatch, BrowserMatch
+import deskbar, deskbar.Indexer, deskbar.Handler
+from deskbar.Watcher import FileWatcher
+from deskbar.BrowserMatch import get_url_host, is_preferred_browser, on_customize_search_shortcuts, on_entry_key_press, load_shortcuts
+from deskbar.BrowserMatch import BrowserSmartMatch, BrowserMatch
 
 def _check_requirements():
-	if deskbar.UNINSTALLED_DESKBAR:
-		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
+#	if deskbar.UNINSTALLED_DESKBAR:
+#		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 		
 	if is_preferred_browser("epiphany"):
-		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
+		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 	else:
-		return (deskbar.handler.HANDLER_IS_NOT_APPLICABLE, "Epiphany is not your preferred browser, not using it.", None)
+		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Epiphany is not your preferred browser, not using it.", None)
 	
 def _check_requirements_search():
 	callback = lambda: on_customize_search_shortcuts(smart_bookmarks, shortcuts_to_smart_bookmarks_map)
 	
-	if deskbar.UNINSTALLED_DESKBAR:
-		return (deskbar.handler.HANDLER_IS_CONFIGURABLE, "You can set shortcuts for your searches.", callback)
+#	if deskbar.UNINSTALLED_DESKBAR:
+#		return (deskbar.Handler.HANDLER_IS_CONFIGURABLE, "You can set shortcuts for your searches.", callback)
 		
 	if is_preferred_browser("epiphany"):
-		return (deskbar.handler.HANDLER_IS_CONFIGURABLE, "You can set shortcuts for your searches.", callback)
+		return (deskbar.Handler.HANDLER_IS_CONFIGURABLE, _("You can set shortcuts for your searches."), callback)
 	else:
-		return (deskbar.handler.HANDLER_IS_NOT_APPLICABLE, "Epiphany is not your preferred browser, not using it.", None)
+		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Epiphany is not your preferred browser, not using it.", None)
 	
 HANDLERS = {
 	"EpiphanyBookmarksHandler": {
@@ -53,9 +53,9 @@ bookmarks = None
 smart_bookmarks = None
 shortcuts_to_smart_bookmarks_map = {}
 
-class EpiphanyHandler(deskbar.handler.Handler):
-	def __init__(self, watched_file, callback):
-		deskbar.handler.Handler.__init__(self, "web-browser.png")
+class EpiphanyHandler(deskbar.Handler.Handler):
+	def __init__(self, watched_file, callback, icon="stock_bookmark"):
+		deskbar.Handler.Handler.__init__(self, icon)
 		self.watched_file = watched_file
 		self.watch_callback = callback
 		
@@ -89,18 +89,18 @@ class EpiphanyBookmarksHandler(EpiphanyHandler):
 			smart_bookmarks = parser.get_smart_bookmarks()
 			load_shortcuts(smart_bookmarks, shortcuts_to_smart_bookmarks_map)
 		
-	def query(self, query, max=5):
+	def query(self, query):
 		global bookmarks
-		return bookmarks.look_up(query)[:max]
+		return bookmarks.look_up(query)[:deskbar.DEFAULT_RESULTS_PER_HANDLER]
 
 class EpiphanySearchHandler(EpiphanyBookmarksHandler):
 	def __init__(self):
 		EpiphanyBookmarksHandler.__init__(self)
 	
-	def on_entry_key_press(self, entry, event, applet):
-		return on_entry_key_press(entry, event, applet, shortcuts_to_smart_bookmarks_map)
+	def on_key_press(self, query, shortcut):
+		return on_entry_key_press(query, shortcut, shortcuts_to_smart_bookmarks_map)
 	
-	def query(self, query, max=5):
+	def query(self, query):
 		# if one of the smart bookmarks' shortcuts matches as a prefix,
 		# then only return that bookmark
 		x = query.find(" ")
@@ -109,7 +109,7 @@ class EpiphanySearchHandler(EpiphanyBookmarksHandler):
 			try:
 				b = shortcuts_to_smart_bookmarks_map[prefix]
 				text = query[x+1:]
-				return [BrowserSmartMatch(b._bookmark, b._name, b._url, prefix)]
+				return [BrowserSmartMatch(b.get_handler(), b.name, b.url, prefix, b, icon=b.icon)]
 			except KeyError:
 				# Probably from the b = ... line.  Getting here
 				# means that there is no such shortcut.
@@ -119,7 +119,7 @@ class EpiphanySearchHandler(EpiphanyBookmarksHandler):
 		
 class EpiphanyHistoryHandler(EpiphanyHandler):
 	def __init__(self):
-		EpiphanyHandler.__init__(self, EPHY_HISTORY_FILE, self._parse_history)
+		EpiphanyHandler.__init__(self, EPHY_HISTORY_FILE, self._parse_history, "epiphany-history.png")
 		self._history = None
 		
 	def initialize(self):
@@ -130,8 +130,8 @@ class EpiphanyHistoryHandler(EpiphanyHandler):
 		global favicon_cache
 		self._history = EpiphanyHistoryParser(self, favicon_cache).get_indexer()
 			
-	def query(self, query, max=5):
-		return self._history.look_up(query)[:max]
+	def query(self, query):
+		return self._history.look_up(query)[:deskbar.DEFAULT_RESULTS_PER_HANDLER]
 		
 class EpiphanyBookmarksParser(xml.sax.ContentHandler):
 	def __init__(self, handler, cache):
@@ -144,7 +144,7 @@ class EpiphanyBookmarksParser(xml.sax.ContentHandler):
 		self.href = None
 		self.smarthref = None
 		
-		self._indexer = deskbar.indexer.Index()
+		self._indexer = deskbar.Indexer.Indexer()
 		self._smart_bookmarks = []
 		self._cache = cache;
 		
@@ -189,18 +189,14 @@ class EpiphanyBookmarksParser(xml.sax.ContentHandler):
 			if self.href.startswith("javascript:"):
 				return
 			
-			pixbuf = None
-			try:
-				host = get_url_host(self.href)
-				if host in self._cache:
-					pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(self._cache[host], deskbar.ICON_SIZE, deskbar.ICON_SIZE)
-			except Exception, msg:
-				# Most of the time we have an html page here, it could also be an unrecognized format
-				print 'Error:endElement(%s):Title:%s:%s' % (name.encode("utf8"), self.title, msg)
+			icon = None
+			host = get_url_host(self.href)
+			if host in self._cache:
+				icon = self._cache[host]
 
-			bookmark = BrowserMatch(self.handler, self.title, self.href, pixbuf)
+			bookmark = BrowserMatch(self.handler, self.title, self.href, icon=icon)
 			if self.smarthref != None:
-				bookmark = BrowserSmartMatch(bookmark, self.title, self.smarthref)
+				bookmark = BrowserSmartMatch(self.handler, self.title, self.smarthref, icon=icon, bookmark=bookmark)
 				self._smart_bookmarks.append(bookmark)
 			else:
 				self._indexer.add("%s %s" % (self.title, self.href), bookmark)
@@ -269,7 +265,7 @@ class EpiphanyHistoryParser(xml.sax.ContentHandler):
 		self.icon = None
 		self._id = None;
 	
-		self._indexer = deskbar.indexer.Index()
+		self._indexer = deskbar.Indexer.Indexer()
 
 		self._index_history();
 
@@ -308,13 +304,9 @@ class EpiphanyHistoryParser(xml.sax.ContentHandler):
 			elif self._id == "9":
 				self.icon = self.chars.encode('utf8')
 		elif name == "node":
-			pixbuf = None
-			try:
-				if self.icon in self._cache:
-					pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(self._cache[self.icon], deskbar.ICON_SIZE, deskbar.ICON_SIZE)
-			except Exception, msg:
-				# Most of the time we have an html page here, it could also be an unrecognized format
-				print 'Error:endElement(%s):Title:%s:%s' % (name.encode("utf8"), self.title, msg)
+			icon = None
+			if self.icon in self._cache:
+				icon = self._cache[self.icon]
 
-			item = BrowserMatch(self.handler, self.title, self.url, pixbuf, True)
+			item = BrowserMatch(self.handler, self.title, self.url, True, icon=icon)
 			self._indexer.add("%s %s" % (self.title, self.url), item)
