@@ -453,6 +453,11 @@ class CuemiacTreeView (gtk.TreeView):
 		
 		self.qstring = ""
 
+	def is_ready (self):
+		""" Returns True if the view is ready for user interaction """
+		num_children = self.get_model().iter_n_children (None)
+		return self.get_property ("visible") and num_children
+
 	def clear (self):
 		self.model.clear ()
 	
@@ -463,6 +468,9 @@ class CuemiacTreeView (gtk.TreeView):
 		"""Returns the path to the last visible cell."""
 		model = self.get_model ()
 		iter = model.get_iter_first ()
+		if iter == None:
+			return None
+
 		next = model.iter_next (iter)
 		
 		# Find last category node (they are always visible)
@@ -639,17 +647,23 @@ class CuemiacUI (DeskbarUI):
 		self.box.show ()
 		self.icon_entry.show_all ()
 		
-		self.set_sensitive(False)
-		try:
-			self.applet.set_background_widget(applet)
-		except Exception, msg:
-			pass
-		
+		self.set_sensitive(False)		
 		self.invalid = True
 		
 		self.applet.set_applet_flags(gnomeapplet.EXPAND_MINOR)
 		self.applet.set_flags(gtk.CAN_FOCUS)
+		self.applet.connect('change-background', self.on_change_background)
+		self.on_change_background()
 	
+	def on_change_background (self, *args):
+		pixmap = self.applet.get_background()
+		if pixmap:
+			for widget in (self.applet, self.deskbar_button.button_main, self.deskbar_button.button_arrow):
+				style = widget.get_style().copy()
+				style.bg_pixmap[gtk.STATE_NORMAL] = pixmap
+				style.bg_pixmap[gtk.STATE_INSENSITIVE]  = pixmap
+				widget.set_style(style)
+
 	def close_view(self):
 		self.deskbar_button.button_arrow.set_active (False)
 		self.deskbar_button.button_main.set_active (False)
@@ -781,12 +795,14 @@ class CuemiacUI (DeskbarUI):
 			self.box.pack_start (self.scroll_win)
 			self.cview.append_method = gtk.TreeStore.append
 			self.cview.get_model().set_sort_order(gtk.SORT_DESCENDING)
+			self.history.set_sort_order (gtk.SORT_DESCENDING)
 		else:
 			# We are at a bottom panel. Put entry on bottom, and prepend matches (instead of append).
 			self.box.pack_start (self.scroll_win)
 			self.box.pack_start (self.icon_entry, False)
 			self.cview.append_method = gtk.TreeStore.prepend
 			self.cview.get_model().set_sort_order(gtk.SORT_ASCENDING)
+			self.history.set_sort_order (gtk.SORT_ASCENDING)
 			
 		# Update icon accordingto direction
 		self.on_change_size (self.applet)
@@ -858,12 +874,15 @@ class CuemiacUI (DeskbarUI):
 			return True
 			
 		if event.keyval == 65362: # Up
+			if not self.cview.is_ready () : return
 			self.cview.grab_focus ()
 			last = self.cview.last_visible_path ()
-			self.cview.set_cursor (last)
+			if last != None:
+				self.cview.set_cursor (last)
 			return True
 			
 		if event.keyval == 65364: # Down
+			if not self.cview.is_ready () : return
 			self.cview.grab_focus ()
 			self.cview.set_cursor (self.model.get_path(self.model.get_iter_first()))
 			return True
@@ -888,12 +907,22 @@ class CuemiacUI (DeskbarUI):
 			iter = self.model.get_iter (path)
 			
 		if iter is None:
-			# No selection, select top element # FIXME do this
-			iter = self.model.get_iter_first()
-			while (not self.model.iter_has_child(iter)) or (not self.cview.row_expanded(self.model.get_path(iter))):
-				iter = self.model.iter_next(iter)
-			iter = self.model.iter_children(iter)
+			if self.applet.get_orient () in [gnomeapplet.ORIENT_DOWN, gnomeapplet.ORIENT_LEFT, gnomeapplet.ORIENT_RIGHT]:
+				# No selection, select top element # FIXME do this
+				iter = self.model.get_iter_first()
+				while iter != None and ((not self.model.iter_has_child(iter)) or (not self.cview.row_expanded(self.model.get_path(iter)))):
+					iter = self.model.iter_next(iter)
 
+				if iter != None:
+					iter = self.model.iter_children(iter)
+
+			else:
+				# We are on a bottom panel - select the bottom element in the list 
+				#FIXME: Should we iterate backwards up the list if the hit is a category?
+				path = self.cview.last_visible_path()
+				if path != None:
+					iter = self.model.get_iter (self.cview.last_visible_path())
+				
 		if iter is None:
 			return
 			
@@ -907,6 +936,7 @@ class CuemiacUI (DeskbarUI):
 			self.update_entry_icon (icon=match.get_icon())
 		else:
 			self.entry.set_text("")
+			self.update_entry_icon ()
 			
 	def on_cview_key_press (self, cview, event):
 		# If this is an ordinary keystroke just let the
